@@ -265,6 +265,12 @@ def add_translate_args(parser):
         "Including this flag will disable this check, and empty containers can be used.",
     )
 
+    parser.add_argument(
+        "--container-override",
+        help="Override a tool's container by specifying a new container. This argument should be specified in the "
+        "following (comma separated) format: t1=v1,t2=v2. Eg toolid=container/override:version,toolid2=<container>.",
+    )
+
 
 def add_inputs_args(parser):
     from janis_core import HINTS, HintEnum
@@ -400,6 +406,12 @@ def add_run_args(parser):
         "Including this flag will disable this check, and empty containers can be used.",
     )
 
+    parser.add_argument(
+        "--container-override",
+        help="Override a tool's container by specifying a new container. This argument should be specified in the "
+        "following (comma separated) format: t1=v1,t2=v2. Eg toolid=container/override:version,toolid2=<container>.",
+    )
+
     parser.add_argument(
         "--development",
         action="store_true",
@@ -549,7 +561,8 @@ def add_reconnect_args(parser):
 
 
 def add_query_args(parser):
-    parser.add_argument("--status", help="workflow status", choices=TaskStatus.all())
+    statuses = [v.value for v in TaskStatus.all()]
+    parser.add_argument("--status", help="workflow status", choices=statuses)
     parser.add_argument("--name", help="workflow name")
 
     return parser
@@ -774,6 +787,7 @@ def do_run(args):
         no_store=args.no_store,
         allow_empty_container=args.allow_empty_container,
         check_files=not args.skip_file_check,
+        container_override=parse_container_override_format(args.container_override),
     )
 
     Logger.info("Exiting")
@@ -842,7 +856,10 @@ def do_environment(args):
 
 
 def do_query(args):
-    status = args.status
+    status = None
+    if args.status:
+        status = TaskStatus(args.status.lower())
+
     name = args.name
     tasks = ConfigManager.manager().query_tasks(status=status, name=name)
 
@@ -875,7 +892,30 @@ def do_rawquery(args):
     return print(tabulate.tabulate(result))
 
 
+def parse_container_override_format(container_override):
+    if not container_override:
+        return None
+
+    if "," not in container_override and "=" not in container_override:
+        return {"*": container_override}
+
+    co = {}
+
+    for s in container_override.split(","):
+        split = s.split("=")
+        if len(split) != 2:
+            raise Exception(
+                f"The container-override parameter '{s}' is NOT in the correct format, expected k=v"
+            )
+        co[split[0]] = split[1]
+
+    return co
+
+
 def do_translate(args):
+
+    container_override = parse_container_override_format(args.container_override)
+
     translate(
         tool=args.workflow,
         translation=args.translation,
@@ -883,6 +923,7 @@ def do_translate(args):
         output_dir=args.output_dir,
         force=args.no_cache,
         allow_empty_container=args.allow_empty_container,
+        container_override=container_override,
     )
 
 
