@@ -53,6 +53,7 @@ class Cromwell(Engine):
         super().__setstate__(state)
         self._logger = None
         self._process = None
+        self._timer_thread = None
 
     def __init__(
         self,
@@ -110,6 +111,13 @@ class Cromwell(Engine):
                 identifier, config=config, config_path=config_path
             )
 
+    def add_callback(self, *args, **kwargs):
+        if self._timer_thread is None:
+            self._timer_thread = threading.Event()
+            self.poll_metadata()
+
+        super().add_callback(*args, **kwargs)
+
     @staticmethod
     def from_url(identifier, url):
         if not url:
@@ -196,7 +204,7 @@ class Cromwell(Engine):
             cmd.extend(additional_cromwell_options)
 
         self.port = find_free_port()
-        self.host = f"localhost:{self.port}"
+        self.host = f"127.0.0.1:{self.port}"
 
         cmd.append(f"-Dwebservice.port={self.port}")
         cmd.append(f"-Dwebservice.interface=127.0.0.1")
@@ -265,9 +273,6 @@ class Cromwell(Engine):
                 # exit_function=self.something_has_happened_to_cromwell,
             )
 
-        self._timer_thread = threading.Event()
-        self.poll_metadata()
-
         return self
 
     def did_fail(self, rc):
@@ -677,14 +682,33 @@ class Cromwell(Engine):
         return raw.standard() if raw else raw
 
     def terminate_task(self, identifier) -> TaskStatus:
-        url = self.url_abort(identifier)
+        from time import sleep
 
-        data = parse.urlencode({}).encode()
-        req = request.Request(url, data=data)  # this will make the method "POST"
-        r = request.urlopen(req)
+        try:
 
-        Logger.log("Cromwell (Abort): " + str(r))
+            url = self.url_abort(identifier)
 
-        self.progress_callbacks.pop(identifier)
+            data = parse.urlencode({}).encode()
+            req = request.Request(url, data=data)  # this will make the method "POST"
+            r = request.urlopen(req)
+            data = r.read()
+
+            Logger.debug("Janis has issued abort request to Cromwell: " + str(data))
+
+            taskstatus = self.poll_task(identifier)
+            while taskstatus not in TaskStatus.final_states():
+                Logger.debug(
+                    f"Task status ({taskstatus}) has not moved to final state after aborting..."
+                )
+                sleep(1)
+                taskstatus = self.poll_task(identifier)
+
+            Logger.info(
+                f"Workflow with Cromwell identifier ({identifier} has been terminated ({taskstatus})."
+            )
+
+            self.progress_callbacks.pop(identifier)
+        except Exception as e:
+            raise Exception(f"Failed to abort workflow with id = {identifier} :: {e}")
 
         return TaskStatus.ABORTED
