@@ -3,6 +3,7 @@ import sqlite3
 from datetime import datetime
 from shutil import rmtree
 from typing import Dict, Optional, Union
+from contextlib import contextmanager
 
 from janis_core import Workflow, Logger, Tool
 
@@ -41,7 +42,6 @@ class ConfigManager:
             os.makedirs(config.outputdir, exist_ok=True)
 
         self._connection: Optional[sqlite3.Connection] = None
-        self._cursor: Optional[sqlite3.Cursor] = None
         self._taskDB: Optional[TasksDbProvider] = None
         # self.environmentDB = EnvironmentDbProvider(self.connection, self.cursor)
         # self.engineDB = EngineDbProvider(self.connection, self.cursor)
@@ -53,12 +53,15 @@ class ConfigManager:
     def get_lazy_db_connection(self):
         if self._taskDB is None:
             self._connection = self.db_connection()
-            self._cursor = self._connection.cursor()
 
-            self._taskDB = TasksDbProvider(self._connection, self._cursor)
+            self._taskDB = TasksDbProvider(self._connection)
 
         return self._taskDB
 
+    @contextmanager
+    def with_cursor(self):
+        yield self.get_lazy_db_connection().db.cursor()
+
     def db_connection(self):
         config = JanisConfiguration.manager()
         try:
@@ -119,10 +122,10 @@ class ConfigManager:
 
         forbiddenids = set()
         if store_in_centraldb:
-            self.get_lazy_db_connection()
-            forbiddenids = set(
-                t[0] for t in self._cursor.execute("SELECT wid FROM tasks").fetchall()
-            )
+            with self.with_cursor() as cursor:
+                forbiddenids = set(
+                    t[0] for t in cursor.execute("SELECT wid FROM tasks").fetchall()
+                )
         if outdir:
             if os.path.exists(outdir):
                 # this should theoretically scoop through all the ones in the taskDB and
@@ -158,7 +161,6 @@ class ConfigManager:
             self._connection.commit()
             self._connection.close()
             self._taskDB = None
-            self._cursor = None
             self._connection = None
         return row
 
@@ -180,6 +182,7 @@ class ConfigManager:
         run_in_background=True,
         dbconfig=None,
         allow_empty_container=False,
+        container_override: dict = None,
         check_files=True,
     ) -> WorkflowManager:
 
@@ -200,15 +203,16 @@ class ConfigManager:
             run_in_background=run_in_background,
             dbconfig=dbconfig,
             allow_empty_container=allow_empty_container,
+            container_override=container_override,
             check_files=check_files,
         )
 
     def from_wid(self, wid, readonly=False):
         self.readonly = readonly
-        self.get_lazy_db_connection()
-        path = self._cursor.execute(
-            "SELECT outputdir FROM tasks where wid=?", (wid,)
-        ).fetchone()
+        with self.with_cursor() as cursor:
+            path = cursor.execute(
+                "SELECT outputdir FROM tasks where wid=?", (wid,)
+            ).fetchone()
         if not path:
             expanded_path = fully_qualify_filename(wid)
             if os.path.exists(expanded_path):
