@@ -55,21 +55,16 @@ class WorkflowDbManager:
         self.readonly = readonly
 
         self.connection = self.db_connection()
-        self.cursor = self.connection.cursor()
 
         sqlpath = self.get_sql_path()
-        self.runs = RunDbProvider(db=self.connection, cursor=self.cursor)
+        self.runs = RunDbProvider(db=self.connection)
         self.workflowmetadata = WorkflowMetadataDbProvider(
             sqlpath, wid=wid, readonly=readonly
         )
-        self.progressDB = ProgressDbProvider(
-            db=self.connection, cursor=self.cursor, wid=wid
-        )
+        self.progressDB = ProgressDbProvider(db=self.connection, wid=wid)
 
-        self.outputsDB = OutputDbProvider(
-            db=self.connection, cursor=self.cursor, wid=wid
-        )
-        self.jobsDB = JobDbProvider(db=self.connection, cursor=self.cursor, wid=wid)
+        self.outputsDB = OutputDbProvider(db=self.connection, wid=wid)
+        self.jobsDB = JobDbProvider(db=self.connection, wid=wid)
         self.versionsDB = VersionsDbProvider(dblocation=sqlpath, readonly=readonly)
 
     @staticmethod
@@ -87,7 +82,7 @@ class WorkflowDbManager:
                 Logger.critical("Error when opening DB connection to: " + sqlpath)
                 raise
 
-            wid = RunDbProvider(db=connection, cursor=connection.cursor()).get_latest()
+            wid = RunDbProvider(db=connection).get_latest()
             if not wid:
                 raise Exception("Couldn't get WID in task directory")
 
@@ -102,7 +97,7 @@ class WorkflowDbManager:
             connection = sqlite3.connect(
                 f"file:{WorkflowDbManager.get_sql_path_base(path)}?mode=ro", uri=True
             )
-            runDb = RunDbProvider(db=connection, cursor=connection.cursor())
+            runDb = RunDbProvider(db=connection)
             return runDb.get_latest()
 
         except:
@@ -188,5 +183,4 @@ class WorkflowDbManager:
 
     def close(self):
         self.connection.close()
-        self.cursor = None
         self.connection = None
