@@ -152,6 +152,7 @@ class WorkflowManager:
         run_in_background=True,
         dbconfig=None,
         allow_empty_container=False,
+        container_override: dict = None,
         check_files=True,
     ):
 
@@ -181,6 +182,8 @@ class WorkflowManager:
         # tm.set_status(TaskStatus.PROCESSING)
         tm.database.workflowmetadata.status = TaskStatus.PROCESSING
 
+        tm.database.commit()
+
         spec = get_ideal_specification_for_engine(environment.engine)
         spec_translator = get_translator(spec)
         tool_evaluate = tm.prepare_and_output_workflow_to_evaluate_if_required(
@@ -193,6 +196,7 @@ class WorkflowManager:
             max_cores=max_cores or jc.environment.max_cores,
             max_memory=max_memory or jc.environment.max_ram,
             allow_empty_container=allow_empty_container,
+            container_override=container_override,
             check_files=check_files,
         )
 
@@ -542,7 +546,7 @@ class WorkflowManager:
 
         additional_cromwell_params = []
         if not engine.config:
-            Logger.info("Skipping start mysql as Janis is not managing the config")
+            Logger.info("Skipping start database as Janis is not managing the config")
         else:
             dbconfig: JanisDatabaseConfigurationHelper = self.database.workflowmetadata.dbconfig
             dbtype = dbconfig.which_db_to_use()
@@ -564,9 +568,9 @@ class WorkflowManager:
                     "Skipping database config as '--no-database' option was provided."
                 )
 
-            engine.start_engine(additional_cromwell_options=additional_cromwell_params)
-            # Write the new engine details back into the database (for like PID, host and is_started)
-            self.database.workflowmetadata.engine = engine
+        engine.start_engine(additional_cromwell_options=additional_cromwell_params)
+        # Write the new engine details back into the database (for like PID, host and is_started)
+        self.database.workflowmetadata.engine = engine
 
     def start_mysql_and_prepare_cromwell_config(self):
         scriptsdir = self.get_path_for_component(self.WorkflowManagerPath.mysql)
@@ -608,12 +612,13 @@ class WorkflowManager:
         max_cores=None,
         max_memory=None,
         allow_empty_container=False,
+        container_override: dict = None,
         check_files=True,
     ) -> Tool:
         if self.database.progressDB.has(ProgressKeys.saveWorkflow):
             return Logger.info(f"Saved workflow from task '{self.wid}', skipping.")
 
-        Logger.debug(f"Saving workflow with id '{tool.id()}'")
+        Logger.debug(f"Saving workflow with id '{tool.id()}' to {translator.name}")
 
         outdir_workflow = self.get_path_for_component(self.WorkflowManagerPath.workflow)
         translator.translate(
@@ -627,6 +632,7 @@ class WorkflowManager:
             write_inputs_file=False,
             export_path=os.path.join(outdir_workflow, "original"),
             allow_empty_container=allow_empty_container,
+            container_override=container_override,
         )
 
         Logger.info(f"Saved workflow with id '{tool.id()}' to '{outdir_workflow}'")
@@ -660,6 +666,7 @@ class WorkflowManager:
             max_cores=max_cores,
             max_mem=max_memory,
             allow_empty_container=allow_empty_container,
+            container_override=container_override,
         )
 
         self.evaluate_output_params(
@@ -1085,13 +1092,19 @@ class WorkflowManager:
         return meta.status in TaskStatus.final_states()
 
     @staticmethod
-    def mark_aborted(outputdir, wid) -> bool:
+    def mark_aborted(outputdir, wid: Optional[str]) -> bool:
         try:
-            db = WorkflowDbManager.get_workflow_metadatadb(
-                outputdir, wid, readonly=False
-            )
+            if not wid:
+                db = WorkflowManager.from_path_get_latest(
+                    outputdir, readonly=False
+                ).database.workflowmetadata
+            else:
+                db = WorkflowDbManager.get_workflow_metadatadb(
+                    outputdir, wid, readonly=False
+                )
             db.please_abort = True
             db.kvdb.commit()
+            db.close()
             Logger.info("Marked workflow as aborted, this may take some time full exit")
             return True
         except Exception as e:
